pub trait ComponentInterface {
// Required method
fn process(
messages: InboundComponentMsg<'_>,
) -> Result<Vec<OutboundComponentMsg>, ComponentError>;
}Required Methods
Sourcefn process(
messages: InboundComponentMsg<'_>,
) -> Result<Vec<OutboundComponentMsg>, ComponentError>
fn process( messages: InboundComponentMsg<'_>, ) -> Result<Vec<OutboundComponentMsg>, ComponentError>
Process inbound message, producing zero or more outbound messages in response Note that all state for the component must be stored using the secret mechanism.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.